@@ -40,12 +40,6 @@ class P1(object):
             timestamp=self.generation_date.strftime('%Y%m%d'), version=self.version
         )
 
-    @property
-    def simple_filename(self):
-        return "{prefix}_{distributor}_{timestamp}.zip".format(
-            prefix=self.prefix, distributor=self.distributor, timestamp=self.generation_date.strftime('%Y%m%d')
-        )
-
     @property
     def total(self):
         return self.file['ai'].sum()
@@ -106,9 +100,10 @@ class P1(object):
         P1 contains a curve files diary on zip
         :return: file path
         """
-        zipped_file = ZipFile(os.path.join('/tmp', self.simple_filename), 'w')
         daymin = self.file['timestamp'].min()
         daymax = self.file['timestamp'].max()
+        self.measures_date = daymin
+        zipped_file = ZipFile(os.path.join('/tmp', self.filename + '.zip'), 'w')
         while daymin <= daymax:
             di = daymin
             df = daymin + timedelta(days=1)
@@ -120,6 +115,6 @@ class P1(object):
                 filepath, sep=';', header=False, columns=columns, index=False, line_terminator=';\n'
             )
             daymin = df
-            zipped_file.write(filepath)
+            zipped_file.write(filepath, arcname=self.filename)
         zipped_file.close()
         return zipped_file.filename
